pygeodesy.triaxials.bases._UnOrderedTriaxialBase

Package pygeodesy :: Package triaxials :: Module bases :: Class _UnOrderedTriaxialBase |
[frames] | no frames]

# Class _UnOrderedTriaxialBase

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                          _UnOrderedTriaxialBase

Known Subclasses:
  - _OrderedTriaxialBase
  - , triaxial5.Triaxial_

(INTERNAL) Base class for all unordered triaxial classes.

Instance Methods
__init__(self, a_triaxial, b=None, c=None, **name) New unordered `Triaxial_`. |
__repr__(self) Default `repr(self)`. |
areaKT(self, *p) Approximate the surface area using Knud Thomson's formula (`meter` squared). |
area_p(self, p=1.6075) DEPRECATED on 2026-02-15, use method areaKT. |
ellipse5(self, lat) Get the equatorial or a parallel ellipse of lattitude. |
hartzell4(self, pov, los=False, **name) Compute the intersection of this triaxial's surface with a Line-Of-Sight from a Point-Of-View in space. |
height4(self, x_xyz, y=None, z=None, normal=True, eps=2.220446049250313e-16, **name) Compute the projection on and the height above or below this triaxial's surface. |
normal3d(self, x_xyz, y=None, z=None, length=1.0) Get a 3-D vector on and perpendicular to this triaxial's surface. |
normal4(self, x_xyz, y=None, z=None, height=0, normal=True) Compute a cartesian at a `height` above or below this triaxial's surface. |
sideOf(self, x_xyz, y=None, z=None, eps=8.881784197001252e-16) Is a cartesian on, above or below the surface of this triaxial? |
toBiaxial(self, **name) Convert this triaxial to a biaxial Ellipsoid, provided 2 axes match. |
toEllipsoid(self, **name) Convert this triaxial to a biaxial Ellipsoid, provided 2 axes match. |
toStr(self, prec=9, terse=-3, **name) Return this `Triaxial` as a string. |
Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| R2 Get the authalic earth radius (`meter`), sqrt(area / PI4).
| R3 Get the volumetric earth radius (`meter`), (a * b * c)**(1/3).
| Rauthalic Get the authalic earth radius (`meter`), sqrt(area / PI4).
| Rvolumetric Get the volumetric earth radius (`meter`), (a * b * c)**(1/3).
| a Get the `largest, x` semi-axis (`meter`, conventionally).
| a2 Get `a**2`.
| abc3 Get the semi-axes as 3-tuple `(a, b, c)`.
| area Get the surface area (`meter` squared).
| areaRG Get the surface area using Carlson's symmetric RG form (`meter` squared), see also `Elliptic.fRG`
| b Get the `middle, y` semi-axis (`meter`, same units as `a`).
| b2 Get `b**2`.
| c Get the `smallest, z` semi-axis (`meter`, same units as `a`).
| c2 Get `c**2`.
| e2ab Get the `ab` ellipse' (1st) eccentricity squared (`scalar`), 1 - (b/a)**2.
| e2ac Get the `ac` ellipse' (1st) eccentricity squared (`scalar`), 1 - (c/a)**2.
| e2bc Get the `bc` ellipse' (1st) eccentricity squared (`scalar`), 1 - (c/b)**2.
| isFlat Is this triaxial "flat", too pro-/oblate (`bool`)?
| isOblate Is this triaxial oblate (`bool`)?
| isOrdered Is this triaxial ordered and not spherical (`bool`)?
| isProlate Is this triaxial prolate (`bool`)?
| isSpherical Is this triaxial spherical (`Radius` or INT0)?
| perimeter4ab DEPRECATED on 2026.02.09, use property Ellipse`(a, b).perimeter2k_`.
| perimeter4ac DEPRECATED on 2026.02.09, use property Ellipse`(a, c).perimeter2k_`.
| perimeter4bc DEPRECATED on 2026.02.09, use property Ellipse`(b, c).perimeter2k_`.
| unOrdered Is this triaxial un-ordered and not spherical (`bool`)?
| volume Get the volume (`meter**3`), 4 / 3 * PI * a * b * c.
Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, a_triaxial, b=None, c=None, **name) (Constructor) |
New unordered `Triaxial_`. Arguments: `a_triaxial` - Large, `X` semi-axis (`scalar`, conventionally in `meter`) or an other Triaxial, Triaxial_ or TriaxialB instance. `b` - Middle, `Y` semi-axis (`meter`, same units as `a`), required if `a_triaxial is scalar`, ignored otherwise. `c` - Small, `Z` semi-axis (`meter`, like `b`). `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Invalid semi-axis or -axes. Overrides: object.__init__

### __repr__ (self) (Representation operator) |
Default `repr(self)`. Overrides: object.__repr__

### areaKT (self, *p) |
Approximate the surface area using Knud Thomson's formula (`meter` squared). Arguments: `p` - Exponent (`scalar` > 0), 1.6075 for near-spherical or 1.5849625007 for "near-flat" triaxials.

### area_p (self, p=1.6075) |
DEPRECATED on 2026-02-15, use method areaKT. Decorators: `@deprecated_method`

### ellipse5 (self, lat) |
Get the equatorial or a parallel ellipse of lattitude. Arguments: `lat` - Geodetic latitude (`degrees90`, `str` or `Ang`). Returns: An Ellipse5Tuple`(a, b, height, lat, beta)` with `a`, `b` and `height` measured along this trixial's semi-axis `a`, `b` and `c`, respectively. See Also: Method Ellipsoid.circle4 for further details.

### hartzell4 (self, pov, los=False, **name) |
Compute the intersection of this triaxial's surface with a Line-Of-Sight from a Point-Of-View in space. See Also: Function hartzell4 for further details.

### height4 (self, x_xyz, y=None, z=None, normal=True, eps=2.220446049250313e-16, **name) |
Compute the projection on and the height above or below this triaxial's surface. See Also: Function height4 for further details.

### normal3d (self, x_xyz, y=None, z=None, length=1.0) |
Get a 3-D vector on and perpendicular to this triaxial's surface. Arguments: `x_xyz` - X component (`scalar`) or a cartesian (`Cartesian`, Ecef9Tuple, Vector3d, Vector3Tuple or Vector4Tuple). `y` - Y component (`scalar`), required if `x_xyz` if `scalar`, ignored otherwise. `z` - Z component (`scalar`), like `y`. `length` - Optional, signed length in out-/inward direction (`scalar`). Returns: A `Vector3d(x_, y_, z_)` normalized to `length`, pointing out- or inward for postive respectively negative `length`. Raises: `TriaxialError` - Zero length cartesian or vector. Note: Cartesian `(x, y, z)` must be on this triaxial's surface, use method Triaxial.sideOf to validate. See Also: Methods Triaxial.height4 and Triaxial.sideOf.

### normal4 (self, x_xyz, y=None, z=None, height=0, normal=True) |
Compute a cartesian at a `height` above or below this triaxial's surface. Arguments: `x_xyz` - X component (`scalar`) or a cartesian (`Cartesian`, Ecef9Tuple, Vector3d, Vector3Tuple or Vector4Tuple). `y` - Y component (`scalar`), required if `x_xyz` if `scalar`, ignored otherwise. `z` - Z component (`scalar`), like `y`. `normal` - If `True`, the `height` is perpendicular, plumb to the triaxial's surface, otherwise `radially` to the center of this triaxial (`bool`). Returns: Vector4Tuple`(x, y, z, h)` with the cartesian coordinates `x`, `y` and `z` and `h` the signed, normal distance to the triaxial's surface in `meter`, conventionally. Positive `h` indicates, the cartesian is outside the triaxial, negative `h` means inside. Raises: `TriaxialError` - Zero length cartesian or vector. Note: Cartesian `(x, y, z)` must be on this triaxial's surface, use method Triaxial.sideOf to validate. See Also: Methods Triaxial.normal3d and Triaxial.height4.

### sideOf (self, x_xyz, y=None, z=None, eps=8.881784197001252e-16) |
Is a cartesian on, above or below the surface of this triaxial? Arguments: `x_xyz` - X component (`scalar`) or a cartesian (`Cartesian`, Ecef9Tuple, Vector3d, Vector3Tuple or Vector4Tuple). `y` - Y component (`scalar`), required if `x_xyz` is `scalar`, ignored otherwise. `z` - Z component (`scalar`), like `y`. `eps` - On-surface tolerance (`scalar`, distance squared). Returns: `INT0` if `(x, y, z)` is near this triaxial's surface within tolerance `eps`, otherwise the signed, radial distance squared (`float`), nega-/positive for in- respectively outside this triaxial. See Also: Methods Triaxial.height4 and Triaxial.normal3d.

### toBiaxial (self, **name) |
Convert this triaxial to a biaxial Ellipsoid, provided 2 axes match. Arguments: `name` - Optional `name=NN` (`str`). Returns: An Ellipsoid with north along this `Z` axis if `a == b`, this `Y` axis if `a == c` or this `X` axis if `b == c`. Raises: `TriaxialError` - This `a != b`, `b != c` and `c != a`. See Also: Method Ellipsoid.toTriaxial.

### toEllipsoid (self, **name) |
Convert this triaxial to a biaxial Ellipsoid, provided 2 axes match. Arguments: `name` - Optional `name=NN` (`str`). Returns: An Ellipsoid with north along this `Z` axis if `a == b`, this `Y` axis if `a == c` or this `X` axis if `b == c`. Raises: `TriaxialError` - This `a != b`, `b != c` and `c != a`. See Also: Method Ellipsoid.toTriaxial.

### toStr (self, prec=9, terse=-3, **name) |
Return this `Triaxial` as a string. Arguments: `prec` - Precision, number of decimal digits (0..9). `terse` - Limit the number of items (`int`, 3..11), use `terse=0` or `=None` for all. `name` - Optional name (`str`), to override or `None` to exclude this triaxial's name. Returns: This `Triaxial`'s attributes (`str`). Overrides: named._Named.toStr

Property Details

### R2 Get the authalic earth radius (`meter`), sqrt(area / PI4). Get method: R2(self) - Get the authalic earth radius (`meter`), sqrt(area / PI4). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### R3 Get the volumetric earth radius (`meter`), (a * b * c)**(1/3). Get method: R3(self) - Get the volumetric earth radius (`meter`), (a * b * c)**(1/3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rauthalic Get the authalic earth radius (`meter`), sqrt(area / PI4). Get method: R2(self) - Get the authalic earth radius (`meter`), sqrt(area / PI4). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### Rvolumetric Get the volumetric earth radius (`meter`), (a * b * c)**(1/3). Get method: R3(self) - Get the volumetric earth radius (`meter`), (a * b * c)**(1/3). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a Get the `largest, x` semi-axis (`meter`, conventionally). Get method: a(self) - Get the `largest, x` semi-axis (`meter`, conventionally). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### a2 Get `a**2`. Get method: a2(self) - Get `a**2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### abc3 Get the semi-axes as 3-tuple `(a, b, c)`. Get method: abc3(self) - Get the semi-axes as 3-tuple `(a, b, c)`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### area Get the surface area (`meter` squared). Get method: area(self) - Get the surface area (`meter` squared). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### areaRG Get the surface area using Carlson's symmetric RG form (`meter` squared), see also `Elliptic.fRG` Get method: areaRG(self) - Get the surface area using Carlson's symmetric RG form (`meter` squared), see also `Elliptic.fRG` Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b Get the `middle, y` semi-axis (`meter`, same units as `a`). Get method: b(self) - Get the `middle, y` semi-axis (`meter`, same units as `a`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### b2 Get `b**2`. Get method: b2(self) - Get `b**2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### c Get the `smallest, z` semi-axis (`meter`, same units as `a`). Get method: c(self) - Get the `smallest, z` semi-axis (`meter`, same units as `a`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### c2 Get `c**2`. Get method: c2(self) - Get `c**2`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e2ab Get the `ab` ellipse' (1st) eccentricity squared (`scalar`), 1 - (b/a)**2. Get method: e2ab(self) - Get the `ab` ellipse' (1st) eccentricity squared (`scalar`), 1 - (b/a)**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e2ac Get the `ac` ellipse' (1st) eccentricity squared (`scalar`), 1 - (c/a)**2. Get method: e2ac(self) - Get the `ac` ellipse' (1st) eccentricity squared (`scalar`), 1 - (c/a)**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### e2bc Get the `bc` ellipse' (1st) eccentricity squared (`scalar`), 1 - (c/b)**2. Get method: e2bc(self) - Get the `bc` ellipse' (1st) eccentricity squared (`scalar`), 1 - (c/b)**2. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isFlat Is this triaxial "flat", too pro-/oblate (`bool`)? Get method: isFlat(self) - Is this triaxial "flat", too pro-/oblate (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isOblate Is this triaxial oblate (`bool`)? Get method: isOblate(self) - Is this triaxial oblate (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isOrdered Is this triaxial ordered and not spherical (`bool`)? Get method: isOrdered(self) - Is this triaxial ordered and not spherical (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isProlate Is this triaxial prolate (`bool`)? Get method: isProlate(self) - Is this triaxial prolate (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### isSpherical Is this triaxial spherical (`Radius` or INT0)? Get method: isSpherical(self) - Is this triaxial spherical (`Radius` or INT0)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### perimeter4ab DEPRECATED on 2026.02.09, use property Ellipse`(a, b).perimeter2k_`. Get method: perimeter4ab(self) - DEPRECATED on 2026.02.09, use property Ellipse`(a, b).perimeter2k_`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### perimeter4ac DEPRECATED on 2026.02.09, use property Ellipse`(a, c).perimeter2k_`. Get method: perimeter4ac(self) - DEPRECATED on 2026.02.09, use property Ellipse`(a, c).perimeter2k_`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### perimeter4bc DEPRECATED on 2026.02.09, use property Ellipse`(b, c).perimeter2k_`. Get method: perimeter4bc(self) - DEPRECATED on 2026.02.09, use property Ellipse`(b, c).perimeter2k_`. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### unOrdered Is this triaxial un-ordered and not spherical (`bool`)? Get method: unOrdered(self) - Is this triaxial un-ordered and not spherical (`bool`)? Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### volume Get the volume (`meter**3`), 4 / 3 * PI * a * b * c. Get method: volume(self) - Get the volume (`meter**3`), 4 / 3 * PI * a * b * c. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.